ColorConfig

Struct ColorConfig 

pub struct ColorConfig {
    pub high_bitdepth: bool,
    pub twelve_bit: bool,
    pub mono_chrome: bool,
    pub color_description_present_flag: bool,
    pub color_primaries: ColorPrimaries,
    pub transfer_characteristics: TransferCharacteristics,
    pub matrix_coefficients: MatrixCoefficients,
    pub color_range: bool,
    pub subsampling_x: bool,
    pub subsampling_y: bool,
    pub chroma_sample_position: ChromaSamplePosition,
    pub separate_uv_delta_q: bool,
}

Fields

high_bitdepth: bool

Syntax elements which, together with seq_profile, determine the bit depth.

twelve_bit: bool

Syntax elements which, together with seq_profile, determine the bit depth.

mono_chrome: bool

If set, indicates that the video does not contain U and V color planes. If not set, indicates that the video contains Y, U, and V color planes.

color_description_present_flag: bool

If set, specifies that color_primaries, transfer_characteristics, and matrix_coefficients are present. If not set, specifies that color_primaries, transfer_characteristics and matrix_coefficients are not present.

color_primaries: ColorPrimaries

Defined by the “Color primaries” section of ISO/IEC 23091-4/ITU-T H.273.

transfer_characteristics: TransferCharacteristics

Defined by the “Transfer characteristics” section of ISO/IEC 23091-4/ITU-T H.273.

matrix_coefficients: MatrixCoefficients

Defined by the “Matrix coefficients” section of ISO/IEC 23091-4/ITU-T H.273.

color_range: bool

Binary value that is associated with the VideoFullRangeFlag variable specified in ISO/IEC 23091-4/ITU- T H.273. color range equal to 0 shall be referred to as the studio swing representation and color range equal to 1 shall be referred to as the full swing representation for all intents relating to this specification.

subsampling_x: bool

Specify the chroma subsampling format

subsampling_y: bool

Specify the chroma subsampling format

chroma_sample_position: ChromaSamplePosition

Specifies the sample position for subsampled streams

separate_uv_delta_q: bool

If set, indicates that the U and V planes may have separate delta quantizer values. If not set, indicates that the U and V planes will share the same delta quantizer value.