DecoderModelInfo

Struct DecoderModelInfo 

pub struct DecoderModelInfo {
    pub buffer_delay_length_minus_1: u8,
    pub num_units_in_decoding_tick: u32,
    pub buffer_removal_time_length_minus_1: u8,
    pub frame_presentation_time_length_minus_1: u32,
}

Fields

buffer_delay_length_minus_1: u8

Plus 1 specifies the length of the decoder_buffer_delay and the encoder_buffer_delay syntax elements, in bits.

num_units_in_decoding_tick: u32

The number of time units of a decoding clock operating at the frequency time_scale Hz that corresponds to one increment of a clock tick counter:

buffer_removal_time_length_minus_1: u8

Plus 1 specifies the length of the buffer_removal_time syntax element, in bits.

frame_presentation_time_length_minus_1: u32

Plus 1 specifies the length of the frame_presentation_time syntax element, in bits.