GlobalMotionParams

Struct GlobalMotionParams 

pub struct GlobalMotionParams {
    pub is_global: [bool; 8],
    pub is_rot_zoom: [bool; 8],
    pub is_translation: [bool; 8],
    pub gm_params: [[i32; 6]; 8],
    pub warp_valid: [bool; 8],
    pub gm_type: [WarpModelType; 8],
}

Fields

is_global: [bool; 8]

Specifies whether global motion parameters are present for a particular reference frame.

is_rot_zoom: [bool; 8]

Specifies whether a particular reference frame uses rotation and zoom global motion.

is_translation: [bool; 8]

Specifies whether a particular reference frame uses translation global motion.

gm_params: [[i32; 6]; 8]

gm_params[ ref ][ j ] is set equal to SavedGmParams[ frame_to_show_map_idx ][ ref ][ j ] for ref = LAST_FRAME..ALTREF_FRAME, for j = 0..5.

warp_valid: [bool; 8]

Whether the parameters are valid (see warpValid and section 7.11.3.6)

gm_type: [WarpModelType; 8]

Same as GmType.