pub struct QuantizationParams {}Fields
base_q_idx: u32Indicates the base frame qindex. This is used for Y AC coefficients and as the base value for the other quantizers.
diff_uv_delta: boolIndicates the base frame qindex. This is used for Y AC coefficients and as the base value for the other quantizers.
using_qmatrix: boolSpecifies that the quantizer matrix will be used to compute quantizers.
qm_y: u32Specifies the level in the quantizer matrix that should be used for luma plane decoding.
qm_u: u32Specifies the level in the quantizer matrix that should be used for chroma U plane decoding.
qm_v: u32Specifies the level in the quantizer matrix that should be used for chroma V plane decoding.
delta_q_present: boolSpecifies whether quantizer index delta values are present.
delta_q_res: u32Specifies the left shift which should be applied to decoded quantizer index delta values.
delta_q_y_dc: i32Same as DeltaQYDc
delta_q_u_dc: i32Same as DeltaQUDc
delta_q_u_ac: i32Same as DeltaQUAc
delta_q_v_dc: i32Same as DeltaQVDc
delta_q_v_ac: i32Same as DeltaQVAc