PpsRangeExtension

Struct PpsRangeExtension 

pub struct PpsRangeExtension {
    pub log2_max_transform_skip_block_size_minus2: u32,
    pub cross_component_prediction_enabled_flag: bool,
    pub chroma_qp_offset_list_enabled_flag: bool,
    pub diff_cu_chroma_qp_offset_depth: u32,
    pub chroma_qp_offset_list_len_minus1: u32,
    pub cb_qp_offset_list: [i32; 6],
    pub cr_qp_offset_list: [i32; 6],
    pub log2_sao_offset_scale_luma: u32,
    pub log2_sao_offset_scale_chroma: u32,
}

Fields

log2_max_transform_skip_block_size_minus2: u32

log2_max_transform_skip_block_size_minus2 plus 2 specifies the maximum transform block size for which transform_skip_flag may be present in coded pictures referring to the PPS. When not present, the value of log2_max_transform_skip_block_size_minus2 is inferred to be equal to 0. When present, the value of log2_max_transform_skip_block_size_minus2 shall be less than or equal to MaxTbLog2SizeY − 2.

cross_component_prediction_enabled_flag: bool

When set, specifies that log2_res_scale_abs_plus1 and res_scale_sign_flag may be present in the transform unit syntax for pictures referring to the PPS. When not set, specifies that log2_res_scale_abs_plus1 and res_scale_sign_flag are not present for pictures referring to the PPS.

chroma_qp_offset_list_enabled_flag: bool

When set, specifies that the cu_chroma_qp_offset_flag may be present in the transform unit syntax. When not set, specifies that the cu_chroma_qp_offset_flag is not present in the transform unit syntax.

diff_cu_chroma_qp_offset_depth: u32

Specifies the difference between the luma CTB size and the minimum luma coding block size of coding units that convey cu_chroma_qp_offset_flag.

chroma_qp_offset_list_len_minus1: u32

chroma_qp_offset_list_len_minus1 plus 1 specifies the number of cb_qp_offset_list[ i ] and cr_qp_offset_list[ i ] syntax elements that are present in the PPS.

cb_qp_offset_list: [i32; 6]

Specify offsets used in the derivation of Qp′Cb and Qp′Cr, respectively.

cr_qp_offset_list: [i32; 6]

Specify offsets used in the derivation of Qp′Cb and Qp′Cr, respectively.

log2_sao_offset_scale_luma: u32

The base 2 logarithm of the scaling parameter that is used to scale sample adaptive offset (SAO) offset values for luma samples.

log2_sao_offset_scale_chroma: u32

The base 2 logarithm of the scaling parameter that is used to scale SAO offset values for chroma samples.