ShortTermRefPicSet

Struct ShortTermRefPicSet 

pub struct ShortTermRefPicSet {
    pub inter_ref_pic_set_prediction_flag: bool,
    pub delta_idx_minus1: u8,
    pub delta_rps_sign: bool,
    pub abs_delta_rps_minus1: u16,
    pub num_negative_pics: u8,
    pub num_positive_pics: u8,
    pub used_by_curr_pic_s0: [bool; 65],
    pub used_by_curr_pic_s1: [bool; 65],
    pub delta_poc_s0: [i32; 65],
    pub delta_poc_s1: [i32; 65],
    pub num_delta_pocs: u32,
}

Fields

inter_ref_pic_set_prediction_flag: bool

When set, specifies that the stRpsIdx-th candidate short-term RPS is predicted from another candidate short-term RPS, which is referred to as the source candidate short-term RPS.

delta_idx_minus1: u8

delta_idx_minus1 plus 1 specifies the difference between the value of stRpsIdx and the index, into the list of the candidate short-term RPSs specified in the SPS, of the source candidate short-term RPS.

delta_rps_sign: bool

delta_rps_sign and abs_delta_rps_minus1 together specify the value of the variable deltaRps.

abs_delta_rps_minus1: u16

delta_rps_sign and abs_delta_rps_minus1 together specify the value of the variable deltaRps.

num_negative_pics: u8

specifies the number of entries in the stRpsIdx-th candidate short-term RPS that have picture order count values less than the picture order count value of the current picture.

num_positive_pics: u8

specifies the number of entries in the stRpsIdx-th candidate short-term RPS that have picture order count values greater than the picture order count value of the current picture.

used_by_curr_pic_s0: [bool; 65]

Same as UsedByCurrPicS0 in the specification.

used_by_curr_pic_s1: [bool; 65]

Same as UsedByCurrPicS1 in the specification.

delta_poc_s0: [i32; 65]

Same as DeltaPocS0 in the specification.

delta_poc_s1: [i32; 65]

Same as DeltaPocS1 in the specification.

num_delta_pocs: u32

Same as NumDeltaPocs in the specification.