PictureData

Struct PictureData 

pub struct PictureData {
    pub nalu_type: NaluType,
    pub no_rasl_output_flag: bool,
    pub pic_output_flag: bool,
    pub valid_for_prev_tid0_pic: bool,
    pub slice_pic_order_cnt_lsb: i32,
    pub pic_order_cnt_msb: i32,
    pub pic_order_cnt_val: i32,
    pub no_output_of_prior_pics_flag: bool,
    pub first_picture_after_eos: bool,
    pub pic_latency_cnt: i32,
    pub needed_for_output: bool,
    pub short_term_ref_pic_set_size_bits: u32,
    /* private fields */
}
Data associated with an h.265 picture. Most fields are extracted from the slice header and kept for future processing.

Fields

nalu_type: NaluTypeno_rasl_output_flag: boolpic_output_flag: boolvalid_for_prev_tid0_pic: boolslice_pic_order_cnt_lsb: i32pic_order_cnt_msb: i32pic_order_cnt_val: i32no_output_of_prior_pics_flag: boolfirst_picture_after_eos: boolpic_latency_cnt: i32needed_for_output: boolshort_term_ref_pic_set_size_bits: u32

Implementations

Source

impl PictureData

pub fn new_from_slice( slice: &Slice<'_>, first_picture_in_bitstream: bool, first_picture_after_eos: bool, prev_tid0_pic: Option<&PictureData>, max_pic_order_cnt_lsb: i32, ) -> Self

Instantiates a new PictureData from a slice.

See 8.1.3 Decoding process for a coded picture with nuh_layer_id equal to 0.

This will also call the picture order count process (clause 8.3.1) to correctly initialize the POC values.

pub fn is_ref(&self) -> bool

Whether the current picture is a reference, either ShortTerm or LongTerm.

pub fn set_reference(&mut self, reference: Reference)

pub fn reference(&self) -> &Reference