Function cros_codecs::decoded_frame_size
source · [−]pub fn decoded_frame_size(format: DecodedFormat, width: u16, height: u16) -> usizeExpand description
Returns the size required to store a frame of format with size widthxheight, without any
padding. This is the minimum size of the destination buffer passed to nv12_copy or
i420_copy.