Struct cros_codecs::utils::vaapi::ParsedStreamMetadata
source · [−]pub(crate) struct ParsedStreamMetadata {
pub(crate) context: Rc<Context>,
config: Config,
pub(crate) surface_pool: SurfacePoolHandle,
pub(crate) min_num_surfaces: usize,
pub(crate) display_resolution: Resolution,
pub(crate) map_format: Rc<VAImageFormat>,
pub(crate) rt_format: u32,
pub(crate) profile: i32,
}Fields
context: Rc<Context>A VAContext from which we can decode from.
config: ConfigThe VAConfig that created the context. It must kept here so that it does not get dropped while it is in use.
surface_pool: SurfacePoolHandleA pool of surfaces. We reuse surfaces as they are expensive to allocate.
min_num_surfaces: usizeThe number of surfaces required to parse the stream.
display_resolution: ResolutionThe decoder current display resolution.
map_format: Rc<VAImageFormat>The image format we will use to map the surfaces. This is usually the same as the surface’s internal format, but occasionally we can try mapping in a different format if requested and if the VA-API driver can do it.
rt_format: u32The rt_format parsed from the stream.
profile: i32The profile parsed from the stream.